@@ -2,6 +2,7 @@
 // Licence: Lesser GNU Public License 2.1 (LGPL)
 
 #define BUILDING_XYLIB
+
 #include "pdcif.h"
 
 #include <map>
@@ -516,7 +517,7 @@ void t_on_loop_finish::operator()(IteratorT, IteratorT) const
 
 } // anonymous namespace
 
-void PdCifDataSet::load_data(std::istream &f)
+void PdCifDataSet::load_data(std::istream &f, const char*)
 {
     // read file into vector<char>
     f.unsetf(ios::skipws);
